import sys
import cv2
import numpy as np
import os.path as op

cascade = cv2.CascadeClassifier(op.join(op.dirname(__file__), 'cascade.xml'))

DETECTION_SCALE = 1

def find_faces(color_img, neighbors=1, scalefactor=1.05):
    """ Detect faces and return an array with rectangle locations
    
    color_img: (height, width, 3)-shaped array of bytes
    """
    factor = color_img.shape[1] / 640
    color_img = cv2.resize(color_img, (color_img.shape[1] // factor,
                       color_img.shape[0] // factor))
                           
    # Resize and normalize
    img = color_img.copy()
    img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
    img = cv2.equalizeHist(img)
    
    # Perform detection
    faces = cascade.detectMultiScale(img, minNeighbors=neighbors,
                                           scaleFactor=scalefactor)
    
    # Draw green rectangles
    for face in faces:
        x, y, w, h = [x for x in face]
        cv2.rectangle(color_img, (x,y), (x+w,y+h), (0,255,0), 3)
    
    # Return image to LabVIEW.  Note we could have also returned the list of
    # rectangles, and done the overlay there.
    return color_img
